| as_hux_table | R Documentation |
Function converts a gtsummary object to a huxtable object. A user can use this function if they wish to add customized formatting available via the huxtable functions. The huxtable package supports output to PDF via LaTeX, as well as HTML and Word.
as_hux_table(x, include = everything(), return_calls = FALSE)
as_hux_xlsx(x, file, include = everything(), bold_header_rows = TRUE)
x |
( |
include |
Commands to include in output. Input may be a vector of
quoted or unquoted names. tidyselect and gtsummary select helper
functions are also accepted.
Default is |
return_calls |
Logical. Default is |
file |
File path for the output. |
bold_header_rows |
(scalar |
A {huxtable} object
Use the as_hux_xlsx() function to save a copy of the table in an excel file.
To export a single table, pass a gtsummary object as x; the file is written
with a single worksheet. To export multiple tables to one workbook—one table
per worksheet—pass a (optionally named) list of gtsummary objects as x. When
the list is named, the names are used as the worksheet (tab) names; list
elements without a name are assigned a default name of "Sheet {i}".
David Hugh-Jones, Daniel D. Sjoberg
trial |>
tbl_summary(by = trt, include = c(age, grade)) |>
add_p() |>
as_hux_table()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.